Module types

Module types 

Structs

BotCommand
Bot command for setMyCommands API
CallbackQuery
Callback query (button press)
Chat
Telegram Chat object
File
A file as returned by getFilefile_path is the download path under https://api.telegram.org/file/bot<token>/.
InlineKeyboardButton
Inline keyboard button
InlineKeyboardMarkup
Inline keyboard markup
MediaFile
A file attached to a message (video, audio, voice note, document, …).
Message
Telegram Message object
MessageEntity
Message entity (commands, mentions, etc.)
MessageReactionUpdated
Telegram MessageReactionUpdated — a user’s reaction set on a message changed.
PhotoSize
One size of a photo attached to a message.
Sticker
A sticker attached to a message or contained in a sticker set.
StickerSet
A sticker set as returned by getStickerSet.
Update
Telegram Update object received via webhook
User
Telegram User object

Enums

ChatType
Chat type
EntityType
Entity type
ReactionType
Telegram ReactionType — a standard emoji, a custom emoji, or a paid reaction.
ReplyMarkup
Reply markup options
UpdateKind
The kind of update received