Structs
- BotCommand
- Bot command for setMyCommands API
- Callback
Query - Callback query (button press)
- Chat
- Telegram Chat object
- File
- A file as returned by
getFile—file_pathis the download path underhttps://api.telegram.org/file/bot<token>/. - Inline
Keyboard Button - Inline keyboard button
- Inline
Keyboard Markup - Inline keyboard markup
- Media
File - A file attached to a message (video, audio, voice note, document, …).
- Message
- Telegram Message object
- Message
Entity - Message entity (commands, mentions, etc.)
- Message
Reaction Updated - Telegram
MessageReactionUpdated— a user’s reaction set on a message changed. - Photo
Size - One size of a photo attached to a message.
- Sticker
- A sticker attached to a message or contained in a sticker set.
- Sticker
Set - A sticker set as returned by
getStickerSet. - Update
- Telegram Update object received via webhook
- User
- Telegram User object
Enums
- Chat
Type - Chat type
- Entity
Type - Entity type
- Reaction
Type - Telegram
ReactionType— a standard emoji, a custom emoji, or a paid reaction. - Reply
Markup - Reply markup options
- Update
Kind - The kind of update received